//
// Copyright 2000 Perforce Software.  All rights reserved.
//
// This file is part of Perforce - the FAST SCM System.
//
// p4wAllCommands:
//   Comprehensive enum of all commands. Includes method for determining
//   if commands are supported in browse-only mode.

#ifndef p4wAllCommands_H
#define p4wAllCommands_H

//
// All commands handled by p4web

//
// IMPORTANT! Add new commands at the end only! Currently defined enums
// cannot change (to support bookmark-ability).

enum AllCommands {
	
	//
	// No specified command will default to the relocate view which
	// chooses a default command based on heuristics of the url pattern.

	AC_NONE, // 0
	
	//
	// The following commands are usually generated from clicking on
	// a button (and using the current path as the argument). They 
	// generate results in a result pane.
	
	AC_SYNCCMD,    // 1
	AC_RESOLVECMD, // 2
	AC_LOCKCMD,    // 3
	AC_REVERTCMD,  // 4
	AC_CHANGECMD,  // 5
	AC_CHANGEORSUBMITCMD, // 6
	AC_CLIENTCMD,  // 7
	AC_USERCMD,    // 8
	AC_UNLOCKCMD,  // 9
	
	//
	// The following commands generate their own customized output.
	// They usually result from clicking on a link or button.
	
	AC_DESCRIBE,   // 10
	AC_CHANGEEDIT, // 11
	AC_CHANGEPENDINGEDIT,  // 12
	AC_CHANGES,    // 13
	AC_BRANCHVIEW, // 14
	AC_CLIENTVIEW, // 15
	AC_LABELVIEW,  // 16
	AC_USERVIEW,   // 17
	AC_PRINT,      // 18
	AC_DIFF2,      // 19
	AC_ICON,       // 20
	AC_HELP,       // 21
	AC_BROWSEFILE, // 22
	AC_SUBMIT,     // 23
	
	// The following commands are used for buttons that result
	// in a file browser or path browser view, but didn't come
	// directly from menu options. For instance, they may result
	// from button presses or specifying a pattern in an end-user url.
	
	AC_SYNCFILE,     // 24
	AC_EDITFILE,     // 25
	AC_DELETEFILE,   // 26
	AC_LOCKFILE,     // 27
	AC_UNLOCKFILE,   // 28
	AC_REVERTFILE,   // 29
	AC_FILESMATCHING,// 30
	
	// 
	// The following commands are generated from menu options.
	// Those with "FRM" suffixes are used to distinguish between
	// variants that result from button presses or other methods.
	
	AC_SYNCFRM,         // 31
	AC_SUBMITFRM,       // 32
	AC_EDITFRM,         // 33
	AC_ADDFRM,          // 34
	AC_DELETEFRM,       // 35
	AC_FILETYPEFRM,     // 36
	AC_REMOVEFRM,       // 37
	AC_INTEGRATEFRM,    // 38
	AC_RESOLVEFRM,      // 39
	AC_LOCKFRM,         // 40
	AC_UNLOCKFRM,       // 41
	AC_REVERTFRM,       // 42
	AC_SUBMITTEDCHANGELISTS,  // 43
	AC_SYNCFILEFRM,     // 44
	AC_SUBMITFILEFRM,   // 45
	AC_EDITFILEFRM,     // 46
	AC_DELETEFILEFRM,   // 47
	AC_FILETYPEFILEFRM, // 48
	AC_REMOVEFILEFRM,   // 49
	AC_INTEGRATEFILEFRM,// 50
	AC_RESOLVEFILEFRM,  // 51
	AC_LOCKFILEFRM,     // 52
	AC_UNLOCKFILEFRM,   // 53
	AC_REVERTUNCHANGEDFILEFRM,  // 54
	AC_REVERTFILEFRM,   // 55
	AC_UNSYNCED,        // 56
	AC_UNRESOLVED,      // 57
	AC_MISSING,         // 58
	AC_OPENEDUNCHANGED, // 59
	AC_CHANGESUNOPENED, // 60
	AC_FILESMATCHINGFRM,// 61
	AC_OPENEDFILESALL,  // 62
	AC_PENDINGINTEGS,   // 63
	AC_FILETEXTDEPOT,   // 64
	AC_FILETEXTLOCAL,   // 65
	AC_DIFFWVC,         // 66
	AC_DIFFCVH,         // 67
	AC_DIFFWVH,         // 68
	AC_SUBMITTEDCHANGELISTSFILE,  // 69
	AC_LAUNCHEDITOR,    // 70
	AC_DEPOT,           // 71
	AC_CLIENT,          // 72
	AC_WORKSPACE,       // 73
	AC_PENDINGCHANGELISTS,  // 74
	AC_EDITCLIENT,      // 75
	AC_EDITUSER,        // 76
	AC_LABELS,          // 77
	AC_SERVERINFO,      // 78
	AC_CONFIGURATION,   // 79
	AC_CLIENTS,         // 80
	AC_USERS,           // 81
	AC_BRANCHES,        // 82
	AC_PATHBROWSER,     // 83
	
	//
	// Internal: used to parse forms generated by selecting from the menus

	AC_MENUPROCESSOR,   // 84
	AC_ADDPROCESSOR,    // 85
	AC_SYNCPROCESSOR,   // 86
	AC_EDITPROCESSOR,   // 87
	AC_DELETEPROCESSOR, // 88
	AC_RESOLVEPROCESSOR,// 89
	AC_REVERTPROCESSOR, // 90
	AC_LOCKPROCESSOR,   // 91
	AC_UNLOCKPROCESSOR, // 92
	AC_CHANGESPROCESSOR,// 93
	AC_MATCHPROCESSOR,  // 94
	AC_INTEGPROCESSOR,  // 95
	AC_FTYPEPROCESSOR,  // 96
	AC_CONFIGPROCESSOR, // 97
	
	//
	// Miscellaneous

	AC_MIMECONTENT, // 98
	AC_LOGIN,       // 99
	AC_UNSUPPORTED, // 100
	
	//
	// New ac codes go at the end!
	
	AC_ADDSELECTPROCESSOR, // 101
	AC_CLIENTSWITCH,       // 102
	AC_CLIENTSWITCHRES,    // 103
	AC_FILESTATE,          // 104
	AC_ADDFILEFRM,         // 105
	AC_TEXTCONTENT,        // 106
	AC_JOBS,               // 107
	AC_EDITJOB,            // 108
	AC_JOBSPROCESSOR,      // 109
	AC_JOBCMD,             // 110
	AC_JOBVIEW,            // 111
	AC_DELETELABEL,			// 112
	AC_REPLACELABEL,		// 113
	AC_SYNCLABEL,			// 114
	AC_CREATELABEL,			// 115
	AC_CREATELABELTMP,      // 116
	AC_EDITLABEL,			// 117
	AC_LABELFILES,			// 118
	AC_LABELCMD,			// 119
	AC_LABSYNCPROCESSOR,	// 120
	AC_EDITBRANCH,		// 121
	AC_DELETEBRANCH,	// 122
	AC_CREATEBRANCH,	// 123
	AC_INTEGRATEBRANCH,	// 124
	AC_BRANCHCMD,		// 125
	AC_BRANCHDIFF,		// 126
	AC_LABELSPATH,		// 127
	AC_CREATEJOB,		// 128
	AC_DELETEJOB,		// 129
	AC_JOBFIELDS,		// 130
	AC_JOBSPEC,		// 131
	AC_SYNCCHANGERNG,	// 132
	AC_FIXESCHANGE,		// 133
	AC_SYNCCHANGE,		// 134
	AC_FIXESJOB,		// 135
	AC_DELETEJOBCONFIRM,	// 136
	AC_DELETELABELCONFIRM,  // 137
	AC_DELETEBRANCHCONFIRM,  // 138
	AC_DELETECONFPROC,	// 139
	AC_LABELSELECT,		// 140
	AC_LABELSELPROC,	// 141
	AC_ANNOTATE,		// 142
	AC_FULLANNOTATE,	// 143
	AC_CANCELCMD,		// 144
	AC_REVERTCONFIRM,	// 145
	AC_DEPOTPROCESSOR,	// 146
	AC_PATHOPENED,		// 147
	AC_PATHNOOPEN,		// 148
	AC_PATHNOCURRENT,	// 149
	AC_LABELSPROCESSOR,	// 150
	AC_ABOUT,			// 151
	AC_GOTO,			// 152
	AC_ADDFIX,			// 153
	AC_ADDFIXPROCESSOR, // 154
	AC_FIXPENDING,		// 155
	AC_FIXSUBMITTED,	// 156
	AC_FIXPROCESSOR,	// 157
	AC_FIXSUBPROCESSOR,	// 158
	AC_GETJOB,			// 159
	AC_P4CMD,			// 160
	AC_P4CMDTAGGED,		// 161
	AC_P4CMDPANE,		// 162
	AC_P4CMDPROCESSOR,	// 163
	AC_RSSCHGS,			// 164
	AC_RSSJOBS,			// 165
	AC_RSSJOBVIEW,		// 166
	AC_RSSUSER,			// 167
	AC_LOGOUT,			// 168
	AC_LOGOUT2,			// 169
	AC_GETTHUMBNAIL,	// 170
	AC_ECHOURLAsDATA,	// 171
	AC_WORKSPACEFILE,	// 172
	AC_WORKSPACEFILEPATH,	// 173
	AC_EDITCHANGE,			// 174
	AC_EDITTEXTLOCAL,			// 175
	AC_EDITTEXTLOCALPROCESSOR,	// 176
	AC_UPLOADTOLOCAL,			// 177
	AC_UPLOADTOLOCALPROCESSOR,	// 178
	AC_RESOLVEIAPROCESSOR,		// 179
	AC_DEPOTVIEW,				// 180
	AC_DESCRIBEDEAFULT,			// 181
	AC_MULTIUSER,				// 182
	AC_MULTIUSERPROCESSOR,		// 183
	AC_LABELFILESTEXT,			// 184
	AC_DIFF21,					// 185
	AC_EDITNEWCLIENT,			// 186
	AC_BRANCHESPROCESSOR,		// 187
	AC_CLIENTSPROCESSOR,		// 188
	AC_USERSPROCESSOR,			// 189
	AC_DIFFRVW,					// 190
	AC_DIFFSVR,					// 191
	AC_SYNCREV,					// 192
	AC_CHGLISTANNOTATE,			// 193
	AC_CHGLISTFULLANNOTATE,		// 194
	AC_CHGLISTANNOTATEPROC,		// 195
	AC_ADDFILE,					// 196
	AC_DOWNLOADTOLOCAL,			// 197
	AC_EDITEXISTINGCLIENT,		// 198
	AC_SHOWHIDECOLUMNS,			// 199
	AC_SHOWHIDECOLSPROC,		// 200
	AC_P4CMDXML,				// 201
	AC_USERPSWD,				// 202
	AC_GENERALANNOTATE,			// 203
	AC_GOPROCESSOR,				// 204
	AC_DIFF2FILES,				// 205
	AC_DIFF2FILESPROCESSOR,		// 206
	AC_DIFF22,					// 207
	AC_DIFF2DIRS,				// 208
	AC_DIFF2DIRSOUTPUT,			// 209
	AC_SHOWHIDEJOBCOLS,			// 210
	AC_SHOWHIDEFILECOLS,		// 211
};

enum PathMenuCommands {
	PM_PATHBROWSER			= 1,
	PM_DIFF2DIRS			= 1 << 1,
	PM_SYNCCMD				= 1 << 2,
	PM_SYNCFRM				= 1 << 3,
	PM_REMOVEFRM			= 1 << 4,
	PM_EDITFILE				= 1 << 5,
	PM_EDITFRM				= 1 << 6,
	PM_ADDFRM				= 1 << 7,
	FM_DELETEFILE			= 1 << 8,
	PM_DELETEFRM			= 1 << 9,
	PM_REVERTFRM			= 1 << 10,
	PM_FILETYPEFRM			= 1 << 11,
	PM_INTEGRATEFRM			= 1 << 12,
	PM_RESOLVEFRM			= 1 << 13,
	PM_LOCKFRM				= 1 << 14,
	PM_UNLOCKFRM			= 1 << 15,
};

enum FileMenuCommands {
	FM_BROWSEFILE			= 1,
	FM_WORKSPACEFILEPATH	= 1 << 1,
	FM_MIMECONTENT			= 1 << 2,
	FM_SYNCCMD				= 1 << 3,
	FM_SYNCFILEFRM			= 1 << 4,
	FM_REMOVEFILEFRM		= 1 << 5,
	FM_EDITFILE				= 1 << 6,
	FM_ADDFILEFRM			= 1 << 7,
	FM_REVERTCONFIRM		= 1 << 8,
	FM_FILETEXTDEPOT		= 1 << 9,
	FM_FILETEXTLOCAL		= 1 << 10,
	FM_LAUNCHEDITOR			= 1 << 11,
	FM_EDITTEXTLOCAL		= 1 << 12,
	FM_UPLOADTOLOCAL		= 1 << 13,
	FM_DIFF_WVC_CVH			= 1 << 14,
	FM_DIFFWVH				= 1 << 15,
	FM_DIFF21				= 1 << 16,
	FM_FILETYPEFILEFRM		= 1 << 17,
	FM_INTEGRATEFILEFRM		= 1 << 18,
	FM_LOCKFILEFRM			= 1 << 19,
	FM_UNLOCKFILEFRM		= 1 << 20,
	FM_RESOLVEFILEFRM		= 1 << 21,
};

enum FileLogMenuCommands {
	RH_MIMECONTENT		= 1,
	RH_FILETEXTDEPOT	= 1 << 1,
	RH_SEPARATOR		= 1 << 2,
	RH_DIFF21			= 1 << 3,
	RH_DIFFSVR			= 1 << 4,
	RH_DIFFRVW			= 1 << 5,
	RH_SEPARATOR2		= 1 << 6,
	RH_SYNCREV			= 1 << 7,
};

//
// Tab values

enum TabType { TT_NOTAB, TT_FILE, TT_PENDING, TT_SUBMITTED, TT_BRANCH, TT_LABEL,
	TT_CLIENT, TT_USER, TT_JOB, TT_SETTINGS, TT_P4CMD };
	

class p4wAllCommands {

public:
				p4wAllCommands() {}
	virtual			~p4wAllCommands() {}

	//
	// Determine if command is supported for browse-only mode
	
	static	int		CanBrowse( AllCommands cmd );
	
	//
	// Return true only if certain this is a path browser comand
	
	static	int		IsPathBrowser( AllCommands cmd );
	
	//
	// Return true only if certain this is a file browser command
	
	static  int		IsFileBrowser( AllCommands cmd );
	
	//
	// Return 1 only if the node portion of the url is not
	// expected to be a file
	
	static int		NodeNotFile( AllCommands cmd );

	//
	// Return 1 only if this command is to show
	// the recent activity icon
	
	static int		ShowRecentActivity( AllCommands ac );
	
	//
	// Return 1 only if the p4 command is allowed to be run when
	// in standard mode. 
	
	static int		AllowedInStandardMode( char *cmd );

	//
	// Returns the current tab value based on the current
	// ac code
	
	static TabType GetTab( AllCommands ac );

			
};

#endif // p4wAllCommands_H
