//
// Copyright 2002 Perforce Software.  All rights reserved.
//
// This file is part of Perforce - the FAST SCM System.
//
// p4wDescribeDefaultView:
//   Describe default client by invoking p4 opened -C <clientname> -c default


#include <stdlib.h>
#include <string.h>

#include <p4wp4.h>

#include "p4wView.h"
#include "p4wMenuPane.h"
#include "p4wDescribeDefaultView.h"


p4wDescribeDefaultView::p4wDescribeDefaultView( p4wRequest & Request )
	: p4wView( Request )
{
	//
	// Set the short and the long versions of the title
	
	fShortTitle.Set( "Default Changelist" );
	fFullTitle << "Default Changelist Detail";
}

p4wDescribeDefaultView::~p4wDescribeDefaultView()
{
}

void p4wDescribeDefaultView::RenderContent()
{
	//
	// Send the describe results to the describe pane.

	const StrPtr *arg = fRequest.GetDynArg( "arg" );
	if (!arg)
		return;
	
	p4wDescribeDefaultPane describePane( *this, fRequest );
	char *cli = strchr(arg->Text(), '@');
	if (cli)
	{
		*cli++ = '\0';
		describePane.SetUser(arg->Text());
	}
	else
	{
		cli = arg->Text();
		describePane.SetUser(fRequest.GetUser().Text());
	}
	const char *describePaneArgs[] = { "-C", cli, "-c", "default" };
	fRequest.p4( "opened", 4, describePaneArgs, &describePane );

	//
	// Wait for the pane to draw.
	
	fRequest.p4Wait();
}

void p4wDescribeDefaultView::RenderMenu()
{
	//
	// Draw the menu bar
	
	p4wMenuPane menuPane( *this, fRequest, "describe" );
	menuPane.Render( NULL );
}
