//
// Copyright 2001 Perforce Software.  All rights reserved.
//
// This file is part of Perforce - the FAST SCM System.
//
// p4wJobView:
//   Issue the p4 job command to display a job and optionally 
//   display the fixes to the job.

#include <stdlib.h>
#include <string.h>

#include <p4wp4.h>

#include "p4wView.h"
#include "p4wJobView.h"

#include "p4wMenuPane.h"
#include "p4wJobPane.h"

p4wJobView::p4wJobView( p4wRequest & Request )
	: p4wView( Request )
{
	//
	// Set the short and the long versions of the title
	
	if( fRequest.GetCmd() == AC_FIXESJOB ) {
		fShortTitle.Set( "Fixes for job" );
		fFullTitle << "Fixes for job " << fRequest.GetURL();
		
	} else {
		fShortTitle.Set( "Job Detail" );
		fFullTitle << "Job " << fRequest.GetURL();
	}
}

p4wJobView::~p4wJobView()
{
}

void p4wJobView::RenderContent()
{
	//
	// Issue job command and send data to job pane
	
	const char *jobPaneArgs[] = { "-o", fRequest.GetURL().Text() };
	p4wJobPane jobPane( *this, fRequest, 0 );
	
	fRequest.p4( "job", 2, jobPaneArgs, &jobPane );
	fRequest.p4Wait();
	
	//
	// If this is a fixes request, also invoke fixes -j job
	// if we didn't encounter a fatal error.
	
	if( jobPane.FatalError() )
		return;

	const StrPtr *jf  = fRequest.GetStateArg( "jf" );

	if ( (jf && *jf == "y") || fRequest.GetCmd() == AC_FIXESJOB )
	{
		fRequest.p4Arg( "-j" );
		fRequest.p4Arg( fRequest.GetURL().Text() );
		fRequest.p4( "fixes", 0, 0, &jobPane );
		fRequest.p4Wait();
	}
}

void p4wJobView::RenderMenu()
{
	//
	// Draw the menu bar
	
	p4wMenuPane menuPane( *this, fRequest, "job" );
	menuPane.Render( NULL );
}
