//
// Copyright 2000 Perforce Software.  All rights reserved.
//
// This file is part of Perforce - the FAST SCM System.
//
// p4wTextContentView:
//   Renders output of print command using mime type determined by file suffix.


// -------------------------------------
// Includes
//
#include <stdio.h>
#include <string.h>

#include <p4wp4.h>

#include "p4wTextContentView.h"
#include "p4wMimeContentPane.h"

p4wTextContentView::p4wTextContentView(p4wRequest & Request)
	: p4wMimeContentView(Request)
{
}

p4wTextContentView::~p4wTextContentView()
{
}

// -------------------------------------
// Render this view.
//
void p4wTextContentView::Render()
{
	//
	// Request file text at head rev unless we have revision argument.
	
	const StrPtr *rev1 = fRequest.GetStateArg( "rev1" );
	const StrPtr *srev = fRequest.GetDynArg( "sr" );
	const StrPtr *srevState = fRequest.GetStateArg( "sr" );
	
	//
	// If both dynamic & state parameters for sr are set, dynamic
	// wins...set srev to winner
	
	if( !srev && srevState )
		srev = srevState;
	
	StrBuf path;
		
	path.Set( fRequest.GetPath() );
		
	if( rev1 ) {
		path << "#" << rev1;
	} else if( srev ) {
		path << "@" << srev;
	}

	fRequest << "HTTP/1.0 200 OK" << crlf;
	fRequest << "Content-Type: text/plain" << crlf;
	fRequest << crlf;

	p4wMimeContentPane printPane( *this, fRequest );
	const char *printPaneArgs[] = { "-q", path.Text() };
	fRequest.p4("print", 2, printPaneArgs, &printPane);
	fRequest.p4Wait();
}
